==> open-xchange-gui_6.14.0.0.orig.tar.gz: open-xchange-gui-6.14.0.0/plugins/com.openexchange.oxupdater/register.js <==
function createContent() {
    var link = newnode("div", { marginTop: "2em", marginBottom: "2em" }, 0, [
        newnode("img", { verticalAlign: "middle", paddingRight: "7px" },
            { src: getFullImgSrc("img/infostore/infostore_save.gif") }),
        newnode("a", 0, { href: "#" }, [addTranslated(
            _("Download OXUpdater for the OXtender for MS Outlook"))])]);
    addDOMEvent(link, "click", function(e) {
        stopEvent(e);
        $("dlIframe").src =
            AjaxRoot + "/updater/installer/default?session=" + session;
    });
    return newnode("div", 0, 0, [link,
        newnode("div", 0, 0, [addTranslated(
            _("When activating this option an installation wizard will be launched."))]),
        newnode("div", 0, 0, [addTranslated(
            _("Follow the instructions and install the OXUpdater."))]),
        newnode("div", 0, 0, [addTranslated(
            _("The OXUpdater will inform you of any OXtender for MS Outlook updates."))]),
        newnode("div", 0, 0, [addTranslated(
            _("You can download the updates from within the OXUpdater."))])
    ]);
}

var node = new ox.Configuration.LeafNode("configuration/outlook.updater",
                                         _("Outlook OXtender"));

if (configGetKey("modules")["com.openexchange.wizzard"]) {
    var imgpath = "../../plugins/com.openexchange.oxupdater/images/";
    var tab = {
        name: "oxupdater",
        enabled: false,
        visible: true,
        position: 0,

        headerImage: newnode("img", { padding: "5px" },
                                    { src: getFullImgSrc(imgpath + "wizard_d.png") }),

        welcome_node: newnode("tr", 0 , 0, [
            newnode("td", { paddingTop: "5px", paddingleft: "5px" }, 0, [
                newnode("img", 0, { className: "wizzardGridBox",
                                    src: getFullImgSrc(imgpath + "wizard_mini.png") })
            ]),
            newnode("td", { paddingTop: "5px" }, 0, [
                addTranslated(_("Download OXUpdater"))
            ])
        ]),
        
        content: createContent(),

        draw: function(wizard) {
            $("popup.wizzard.next").value = _("Next");
            $("popup.wizzard.back").value = _("Previous");
            
            var title = $("popup.wizzard.header").getElementsByTagName("span")[0];
            removeChildNodes(title);
            if (!this.title) {
                this.title = addTranslated(format(
                    _("Step %d. Download OXUpdater"), this.position));
            }
            title.appendChild(this.title);
            
            var header = document.getElementById("wizzardHeaderTitle");     
            removeChildNodes(header);
            header.appendChild(document.createTextNode(_("OXUpdater")));
            
            this.headerImage.src = getFullImgSrc(imgpath + "wizard.png");

            var base = document.getElementById("wizzardConten");
            removeChildNodes(base);
            base.appendChild(this.content);
        },
        next: function(callback) {
            this.headerImage.src = getFullImgSrc(imgpath + "wizard.png");
            callback();
        },
        previous: function(callback) {
            this.headerImage.src = getFullImgSrc(imgpath + "wizard_d.png");
            callback();
        }
    };
    temporary.services.provide("com.openexchange.wizard", tab);
} else {
    var coou = "com.openexchange.oxupdater";
    var menu = MenuNodes.createSmallButtonContext(coou + ".menu",
        "Microsoft Outlook");
    MenuNodes.createSmallButton(menu, coou + ".button", "Download OXtender",
        getFullImgSrc("img/infostore/infostore_save.gif"),
        getFullImgSrc("img/infostore/infostore_save_d.gif"),
        function() { triggerEvent("OX_Switch_View", node.id); });
    addMenuNode(menu.node, MenuNodes.FIXED, 3);
    changeDisplay("portal", coou + ".menu");
    menuarrows[coou] = {};
    register("OX_SELECTED_ITEMS_CHANGED", function() {
        menuglobalzaehler = 0;
        menuarrows[coou][coou + ".menu"] = [];
        menu_display_contents(coou, coou + ".menu", true, coou + ".button");
    });
    if (currentpath2[0] == "portal") showNode(coou + ".menu");
}

var page = new ox.Configuration.Page(node, _("Outlook OXtender"), false);
page.viewModified = function() { return false; };
var widget = new ox.UI.Widget();
widget.content = createContent();
widget.addContent = function() { this.parent.addRow(this.content); };
page.addWidget(widget);

==> open-xchange-gui_6.16.1.0.orig.tar.gz: open-xchange-gui-6.16.1.0/plugins/com.openexchange.oxupdater/register.js <==
function createContent() {
    var link = newnode("div", { marginTop: "2em", marginBottom: "2em" }, 0, [
        newnode("img", { verticalAlign: "middle", paddingRight: "7px" },
            { src: getFullImgSrc("img/infostore/infostore_save.gif") }),
        newnode("a", 0, { href: "#" }, [addTranslated(
            _("Download OXUpdater for the OXtender for MS Outlook"))])]);
    addDOMEvent(link, "click", function(e) {
        stopEvent(e);
        $("dlIframe").src =
            AjaxRoot + "/updater/installer/default?session=" + session;
    });
    return newnode("div", 0, 0, [link,
        newnode("div", 0, 0, [addTranslated(
            _("When activating this option an installation wizard will be launched."))]),
        newnode("div", 0, 0, [addTranslated(
            _("Follow the instructions and install the OXUpdater."))]),
        newnode("div", 0, 0, [addTranslated(
            _("The OXUpdater will inform you of any OXtender for MS Outlook updates."))]),
        newnode("div", 0, 0, [addTranslated(
            _("You can download the updates from within the OXUpdater."))])
    ]);
}

var node = new ox.Configuration.LeafNode("configuration/outlook.updater",
                                         _("Outlook OXtender"));

if (configGetKey("modules")["com.openexchange.wizard"]) {
    var imgpath = "../../plugins/com.openexchange.oxupdater/images/";
    var tab = {
        name: "oxupdater",
        enabled: false,
        visible: true,
        position: 0,

        headerImage: newnode("img", { padding: "5px" },
                                    { src: getFullImgSrc(imgpath + "wizard_d.png") }),

        welcome_node: newnode("tr", 0 , 0, [
            newnode("td", { paddingTop: "5px", paddingleft: "5px" }, 0, [
                newnode("img", 0, { className: "wizzardGridBox",
                                    src: getFullImgSrc(imgpath + "wizard_mini.png") })
            ]),
            newnode("td", { paddingTop: "5px" }, 0, [
                addTranslated(_("Download OXUpdater"))
            ])
        ]),
        
        content: createContent(),

        draw: function(wizard) {
            $("popup.wizzard.next").value = _("Next");
            $("popup.wizzard.back").value = _("Previous");
            
            var title = $("popup.wizzard.header").getElementsByTagName("span")[0];
            removeChildNodes(title);
            if (!this.title) {
                this.title = addTranslated(format(
                    _("Step %d. Download OXUpdater"), this.position));
            }
            title.appendChild(this.title);
            
            var header = document.getElementById("wizzardHeaderTitle");     
            removeChildNodes(header);
            header.appendChild(document.createTextNode(_("OXUpdater")));
            
            this.headerImage.src = getFullImgSrc(imgpath + "wizard.png");

            var base = document.getElementById("wizzardConten");
            removeChildNodes(base);
            base.appendChild(this.content);
        },
        next: function(callback) {
            this.headerImage.src = getFullImgSrc(imgpath + "wizard.png");
            callback();
        },
        previous: function(callback) {
            this.headerImage.src = getFullImgSrc(imgpath + "wizard_d.png");
            callback();
        }
    };
    temporary.services.provide("com.openexchange.wizard", tab);
} else {
    var coou = "com.openexchange.oxupdater";
    var menu = MenuNodes.createSmallButtonContext(coou + ".menu",
        _("Microsoft Outlook"));
    MenuNodes.createSmallButton(menu, coou + ".button", _("Download OXtender"),
        getFullImgSrc("img/infostore/infostore_save.gif"),
        getFullImgSrc("img/infostore/infostore_save_d.gif"),
        function() { triggerEvent("OX_Switch_View", node.id); });
    addMenuNode(menu.node, MenuNodes.FIXED, 3);
    changeDisplay("portal", coou + ".menu");
    menuarrows[coou] = {};
    register("OX_SELECTED_ITEMS_CHANGED", function() {
        menuglobalzaehler = 0;
        menuarrows[coou][coou + ".menu"] = [];
        menu_display_contents(coou, coou + ".menu", true, coou + ".button");
    });
    if (currentpath2[0] == "portal") showNode(coou + ".menu");
}

var page = new ox.Configuration.Page(node, _("Outlook OXtender"), false);
page.viewModified = function() { return false; };
var widget = new ox.UI.Widget();
widget.content = createContent();
widget.addContent = function() { this.parent.addRow(this.content); };
page.addWidget(widget);
